==> mars-src-1.0.1.tar.gz: mars-src-1.0.1/samples/partial_context_save/host.c <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <stdlib.h>
#include <sys/time.h>
#include <libspe2.h>
#include <mars/mars.h>

#define INFO	\
"\
MARS Partial Context Save Sample				\n\
--------------------------------				\n\
This program is a simple example to show how to create and	\n\
execute a task that does context switches optimized by		\n\
specifying partial context save paramters during task creation.	\n\
								\n\
The task being run in this program is a very simple MPU		\n\
program that yields to perform a context switch.		\n\
								\n\
The first time the task is created and run, a full context	\n\
switch is specified.						\n\
								\n\
The second time the task is created and run, a partial context	\n\
switch is specified.						\n\
\n"

#define TIMER_START(timer)\
{\
	struct timeval tv;\
	gettimeofday(&tv, NULL);\
	timer = tv.tv_sec * 1000000 + tv.tv_usec;\
}

#define TIMER_STOP(timer)\
{\
	struct timeval tv;\
	gettimeofday(&tv, NULL);\
	timer = tv.tv_sec * 1000000 + tv.tv_usec - timer;\
}

extern struct spe_program_handle mpu_task_prog;

static struct mars_context *mars_ctx;
static struct mars_task_id task_id;
static struct mars_task_context_save_unit MARS_TASK_CONTEXT_SAVE_PARTIAL[] =
{
	{ .addr = 0, .size = 0x1000 },
	{ .addr = MARS_TASK_CONTEXT_SAVE_SIZE_MAX - 0x1000, .size = 0x1000 },
	{ .addr = 0, .size = 0 },
};

int run_task_switch(const struct mars_task_context_save_unit *context_save_unit)
{
	int ret;

	ret = mars_task_create(mars_ctx, &task_id, "Task",
		mpu_task_prog.elf_image, context_save_unit);
	if (ret) {
		printf("MARS task create failed! (%d)\n", ret);
		return 1;
	}

	ret = mars_task_schedule(&task_id, NULL, 0);
	if (ret) {
		printf("MARS task schedule failed! (%d)\n", ret);
		return 1;
	}

	ret = mars_task_wait(&task_id, NULL);
	if (ret) {
		printf("MARS task wait failed! (%d)\n", ret);
		return 1;
	}

	ret = mars_task_destroy(&task_id);
	if (ret) {
		printf("MARS task destroy failed! (%d)\n", ret);
		return 1;
	}

	return 0;
}

int main(void)
{
	int ret;
	unsigned long long timer;

	printf(INFO);

	ret = mars_context_create(&mars_ctx, 0, 0);
	if (ret) {
		printf("MARS context create failed! (%d)\n", ret);
		return 1;
	}

	TIMER_START(timer);
	run_task_switch(MARS_TASK_CONTEXT_SAVE_ALL);
	TIMER_STOP(timer);
	printf("Full Context Save took    - %.0f us\n\n", (float)timer);

	TIMER_START(timer);
	run_task_switch(MARS_TASK_CONTEXT_SAVE_PARTIAL);
	TIMER_STOP(timer);
	printf("Partial Context Save took - %.0f us\n", (float)timer);

	ret = mars_context_destroy(mars_ctx);
	if (ret) {
		printf("MARS context destroy failed! (%d)\n", ret);
		return 1;
	}

	return 0;
}

==> mars-src-1.1.0.tar.gz: mars-src-1.1.0/samples/partial_context_save/host.c <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <stdlib.h>
#include <sys/time.h>
#include <libspe2.h>
#include <mars/mars.h>

#define INFO	\
"\
MARS Partial Context Save Sample				\n\
--------------------------------				\n\
This program is a simple example to show how to create and	\n\
execute a task that does context switches optimized by		\n\
specifying partial context save paramters during task creation.	\n\
								\n\
The task being run in this program is a very simple MPU		\n\
program that yields to perform a context switch.		\n\
								\n\
The first time the task is created and run, a full context	\n\
switch is specified.						\n\
								\n\
The second time the task is created and run, a partial context	\n\
switch is specified.						\n\
\n"

#define TIMER_START(timer)\
{\
	struct timeval tv;\
	gettimeofday(&tv, NULL);\
	timer = tv.tv_sec * 1000000 + tv.tv_usec;\
}

#define TIMER_STOP(timer)\
{\
	struct timeval tv;\
	gettimeofday(&tv, NULL);\
	timer = tv.tv_sec * 1000000 + tv.tv_usec - timer;\
}

extern struct spe_program_handle mpu_task_prog;

static struct mars_context *mars_ctx;
static struct mars_task_id task_id;
static struct mars_task_context_save_unit MARS_TASK_CONTEXT_SAVE_PARTIAL[] =
{
	{ .addr = 0, .size = 0x10000 },
	{ .addr = MARS_TASK_CONTEXT_SAVE_SIZE_MAX - 0x12000, .size = 0x12000 },
	{ .addr = 0, .size = 0 },
};

int run_task_switch(const struct mars_task_context_save_unit *context_save_unit)
{
	int ret;

	ret = mars_task_create(mars_ctx, &task_id, "Task",
		mpu_task_prog.elf_image, context_save_unit);
	if (ret) {
		printf("MARS task create failed! (%d)\n", ret);
		return 1;
	}

	ret = mars_task_schedule(&task_id, NULL, 0);
	if (ret) {
		printf("MARS task schedule failed! (%d)\n", ret);
		return 1;
	}

	ret = mars_task_wait(&task_id, NULL);
	if (ret) {
		printf("MARS task wait failed! (%d)\n", ret);
		return 1;
	}

	ret = mars_task_destroy(&task_id);
	if (ret) {
		printf("MARS task destroy failed! (%d)\n", ret);
		return 1;
	}

	return 0;
}

int main(void)
{
	int ret;
	unsigned long long timer;

	printf(INFO);

	ret = mars_context_create(&mars_ctx, 0, 0);
	if (ret) {
		printf("MARS context create failed! (%d)\n", ret);
		return 1;
	}

	TIMER_START(timer);
	ret = run_task_switch(MARS_TASK_CONTEXT_SAVE_ALL);
	if (ret)
		return 1;
	TIMER_STOP(timer);
	printf("Full Context Save took    - %.0f us\n\n", (float)timer);

	TIMER_START(timer);
	ret = run_task_switch(MARS_TASK_CONTEXT_SAVE_PARTIAL);
	if (ret)
		return 1;
	TIMER_STOP(timer);
	printf("Partial Context Save took - %.0f us\n", (float)timer);

	ret = mars_context_destroy(mars_ctx);
	if (ret) {
		printf("MARS context destroy failed! (%d)\n", ret);
		return 1;
	}

	return 0;
}
